@@ -33,10 +33,11 @@
 #  define KXMLRPCCLIENT_DEPRECATED_NO_EXPORT KXMLRPCCLIENT_NO_EXPORT KXMLRPCCLIENT_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KXMLRPCCLIENT_NO_DEPRECATED
 #    define KXMLRPCCLIENT_NO_DEPRECATED
 #  endif
 #endif
 
-#endif
+#endif /* KXMLRPCCLIENT_EXPORT_H */
